// Copyright (c) 2017 VMware, Inc. All Rights Reserved.
//
// Licensed under the Apache License, Version 2.0 (the "License");
// you may not use this file except in compliance with the License.
// You may obtain a copy of the License at
//
//    http://www.apache.org/licenses/LICENSE-2.0
//
// Unless required by applicable law or agreed to in writing, software
// distributed under the License is distributed on an "AS IS" BASIS,
// WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
// See the License for the specific language governing permissions and
// limitations under the License.
import { Component, EventEmitter, Input, Output } from '@angular/core';
import { TranslateService } from '@ngx-translate/core';
import { ConfirmationAcknowledgement } from './confirmation-state-message';
import { CONFIRMATION_DIALOG_TEMPLATE } from './confirmation-dialog.component.html';
import { CONFIRMATION_DIALOG_STYLE } from './confirmation-dialog.component.css';
var ConfirmationDialogComponent = (function () {
    function ConfirmationDialogComponent(translate) {
        this.translate = translate;
        this.opened = false;
        this.dialogTitle = '';
        this.dialogContent = '';
        this.confirmAction = new EventEmitter();
        this.cancelAction = new EventEmitter();
        this.batchInfors = [];
        this.isDelete = false;
    }
    ConfirmationDialogComponent.prototype.open = function (msg) {
        var _this = this;
        this.dialogTitle = msg.title;
        this.dialogContent = msg.message;
        this.message = msg;
        this.translate.get(this.dialogTitle).subscribe(function (res) { return _this.dialogTitle = res; });
        this.translate.get(this.dialogContent, { 'param': msg.param }).subscribe(function (res) { return _this.dialogContent = res; });
        // Open dialog
        this.buttons = msg.buttons;
        this.opened = true;
    };
    Object.defineProperty(ConfirmationDialogComponent.prototype, "batchOverStatus", {
        get: function () {
            if (this.batchInfors.length) {
                return this.batchInfors.every(function (item) { return item.loading === false; });
            }
            return false;
        },
        enumerable: true,
        configurable: true
    });
    ConfirmationDialogComponent.prototype.colorChange = function (list) {
        if (!list.loading && !list.errorState) {
            return 'green';
        }
        else if (!list.loading && list.errorState) {
            return 'red';
        }
        else {
            return '#666';
        }
    };
    ConfirmationDialogComponent.prototype.toggleErrorTitle = function (errorSpan) {
        errorSpan.style.display = (errorSpan.style.display === 'none') ? 'block' : 'none';
    };
    ConfirmationDialogComponent.prototype.close = function () {
        this.batchInfors = [];
        this.opened = false;
    };
    ConfirmationDialogComponent.prototype.cancel = function () {
        if (!this.message) {
            // Inproper condition
            this.close();
            return;
        }
        var data = this.message.data ? this.message.data : {};
        var target = this.message.targetId ? this.message.targetId : 0 /* EMPTY */;
        this.cancelAction.emit(new ConfirmationAcknowledgement(2 /* CANCEL */, data, target));
        this.isDelete = false;
        this.close();
    };
    ConfirmationDialogComponent.prototype.operate = function () {
        if (!this.message) {
            this.close();
            return;
        }
        if (this.batchInfors.length) {
            this.batchInfors.every(function (item) { return item.loading = true; });
            this.isDelete = true;
        }
        var data = this.message.data ? this.message.data : {};
        var target = this.message.targetId ? this.message.targetId : 0 /* EMPTY */;
        var message = new ConfirmationAcknowledgement(1 /* CONFIRMED */, data, target);
        this.confirmAction.emit(message);
    };
    ConfirmationDialogComponent.prototype.confirm = function () {
        if (!this.message) {
            this.close();
            return;
        }
        var data = this.message.data ? this.message.data : {};
        var target = this.message.targetId ? this.message.targetId : 0 /* EMPTY */;
        var message = new ConfirmationAcknowledgement(1 /* CONFIRMED */, data, target);
        this.confirmAction.emit(message);
        this.close();
    };
    return ConfirmationDialogComponent;
}());
export { ConfirmationDialogComponent };
ConfirmationDialogComponent.decorators = [
    { type: Component, args: [{
                selector: 'confirmation-dialog',
                template: CONFIRMATION_DIALOG_TEMPLATE,
                styles: [CONFIRMATION_DIALOG_STYLE]
            },] },
];
/** @nocollapse */
ConfirmationDialogComponent.ctorParameters = function () { return [
    { type: TranslateService, },
]; };
ConfirmationDialogComponent.propDecorators = {
    'confirmAction': [{ type: Output },],
    'cancelAction': [{ type: Output },],
    'batchInfors': [{ type: Input },],
};
//# sourceMappingURL=confirmation-dialog.component.js.map