// Copyright (c) 2017 VMware, Inc. All Rights Reserved.
//
// Licensed under the Apache License, Version 2.0 (the "License");
// you may not use this file except in compliance with the License.
// You may obtain a copy of the License at
//
//    http://www.apache.org/licenses/LICENSE-2.0
//
// Unless required by applicable law or agreed to in writing, software
// distributed under the License is distributed on an "AS IS" BASIS,
// WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
// See the License for the specific language governing permissions and
// limitations under the License.
import { Component, Output, EventEmitter, Input, ViewChild, ChangeDetectionStrategy, ChangeDetectorRef } from '@angular/core';
import { CREATE_EDIT_LABEL_STYLE } from './create-edit-label.component.css';
import { CREATE_EDIT_LABEL_TEMPLATE } from './create-edit-label.component.html';
import { toPromise, clone, compareValue } from '../utils';
import { LabelService } from "../service/label.service";
import { ErrorHandler } from "../error-handler/error-handler";
import { Subject } from "rxjs/Subject";
import { LabelColor } from "../shared/shared.const";
var CreateEditLabelComponent = (function () {
    function CreateEditLabelComponent(labelService, errorHandler, ref) {
        this.labelService = labelService;
        this.errorHandler = errorHandler;
        this.ref = ref;
        this.labelModel = this.initLabel();
        this.labelId = 0;
        this.isLabelNameExist = false;
        this.panelHidden = true;
        this.nameChecker = new Subject();
        this.reload = new EventEmitter();
    }
    CreateEditLabelComponent.prototype.ngOnInit = function () {
        var _this = this;
        this.nameChecker.debounceTime(500).subscribe(function (name) {
            _this.checkOnGoing = true;
            var labelName = _this.currentForm.controls['name'].value;
            toPromise(_this.labelService.getLabels(_this.scope, _this.projectId, labelName))
                .then(function (targets) {
                if (targets && targets.length) {
                    _this.isLabelNameExist = true;
                }
                else {
                    _this.isLabelNameExist = false;
                }
                _this.checkOnGoing = false;
            }).catch(function (error) {
                _this.checkOnGoing = false;
                _this.errorHandler.error(error);
            });
            setTimeout(function () {
                setInterval(function () { return _this.ref.markForCheck(); }, 100);
            }, 3000);
        });
    };
    CreateEditLabelComponent.prototype.ngOnDestroy = function () {
        this.nameChecker.unsubscribe();
    };
    Object.defineProperty(CreateEditLabelComponent.prototype, "labelColor", {
        get: function () {
            return LabelColor;
        },
        enumerable: true,
        configurable: true
    });
    CreateEditLabelComponent.prototype.initLabel = function () {
        return {
            name: '',
            description: '',
            color: '',
            scope: '',
            project_id: 0
        };
    };
    CreateEditLabelComponent.prototype.openModal = function () {
        this.labelModel = this.initLabel();
        this.formShow = true;
        this.isLabelNameExist = false;
        this.labelId = 0;
        this.copeLabelModel = null;
    };
    CreateEditLabelComponent.prototype.editModel = function (labelId, label) {
        this.labelModel = clone(label[0]);
        this.formShow = true;
        this.labelId = labelId;
        this.copeLabelModel = clone(label[0]);
    };
    CreateEditLabelComponent.prototype.openColorPanel = function () {
        this.panelHidden = false;
    };
    CreateEditLabelComponent.prototype.closeColorPanel = function () {
        this.panelHidden = true;
    };
    Object.defineProperty(CreateEditLabelComponent.prototype, "hasChanged", {
        get: function () {
            return !compareValue(this.copeLabelModel, this.labelModel);
        },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(CreateEditLabelComponent.prototype, "isValid", {
        get: function () {
            return !(this.checkOnGoing || this.isLabelNameExist || !(this.currentForm && this.currentForm.valid) || !this.hasChanged || this.inProgress);
        },
        enumerable: true,
        configurable: true
    });
    CreateEditLabelComponent.prototype.existValid = function (text) {
        if (text) {
            this.nameChecker.next(text);
        }
    };
    CreateEditLabelComponent.prototype.onSubmit = function () {
        var _this = this;
        this.inProgress = true;
        if (this.labelId <= 0) {
            this.labelModel.scope = this.scope;
            this.labelModel.project_id = this.projectId;
            toPromise(this.labelService.createLabel(this.labelModel))
                .then(function (res) {
                _this.inProgress = false;
                _this.reload.emit();
                _this.labelModel = _this.initLabel();
            }).catch(function (err) {
                _this.inProgress = false;
                _this.errorHandler.error(err);
            });
        }
        else {
            toPromise(this.labelService.updateLabel(this.labelId, this.labelModel))
                .then(function (res) {
                _this.inProgress = false;
                _this.reload.emit();
                _this.labelModel = _this.initLabel();
            }).catch(function (err) {
                _this.inProgress = false;
                _this.errorHandler.error(err);
            });
        }
    };
    CreateEditLabelComponent.prototype.onCancel = function () {
        this.inProgress = false;
        this.labelModel = this.initLabel();
        this.formShow = false;
    };
    return CreateEditLabelComponent;
}());
export { CreateEditLabelComponent };
CreateEditLabelComponent.decorators = [
    { type: Component, args: [{
                selector: 'hbr-create-edit-label',
                template: CREATE_EDIT_LABEL_TEMPLATE,
                styles: [CREATE_EDIT_LABEL_STYLE],
                changeDetection: ChangeDetectionStrategy.Default
            },] },
];
/** @nocollapse */
CreateEditLabelComponent.ctorParameters = function () { return [
    { type: LabelService, },
    { type: ErrorHandler, },
    { type: ChangeDetectorRef, },
]; };
CreateEditLabelComponent.propDecorators = {
    'currentForm': [{ type: ViewChild, args: ['labelForm',] },],
    'projectId': [{ type: Input },],
    'scope': [{ type: Input },],
    'reload': [{ type: Output },],
};
//# sourceMappingURL=create-edit-label.component.js.map