// Copyright (c) 2017 VMware, Inc. All Rights Reserved.
//
// Licensed under the Apache License, Version 2.0 (the "License");
// you may not use this file except in compliance with the License.
// You may obtain a copy of the License at
//
//    http://www.apache.org/licenses/LICENSE-2.0
//
// Unless required by applicable law or agreed to in writing, software
// distributed under the License is distributed on an "AS IS" BASIS,
// WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
// See the License for the specific language governing permissions and
// limitations under the License.
import { Directive, Input } from '@angular/core';
import { NG_VALIDATORS, Validators } from '@angular/forms';
var DateValidatorDirective = (function () {
    function DateValidatorDirective() {
        this.valFn = Validators.nullValidator;
    }
    DateValidatorDirective.prototype.ngOnChanges = function (changes) {
        var change = changes['dateValidator'];
        if (change) {
            this.valFn = dateValidator();
        }
        else {
            this.valFn = Validators.nullValidator;
        }
    };
    DateValidatorDirective.prototype.validate = function (control) {
        return this.valFn(control) || Validators.nullValidator;
    };
    return DateValidatorDirective;
}());
export { DateValidatorDirective };
DateValidatorDirective.decorators = [
    { type: Directive, args: [{
                selector: '[dateValidator]',
                providers: [{ provide: NG_VALIDATORS, useExisting: DateValidatorDirective, multi: true }]
            },] },
];
/** @nocollapse */
DateValidatorDirective.ctorParameters = function () { return []; };
DateValidatorDirective.propDecorators = {
    'dateValidator': [{ type: Input },],
};
export function dateValidator() {
    return function (control) {
        var controlValue = control.value;
        var valid = true;
        if (controlValue) {
            var regYMD = /^(19|20)\d\d([- /.])(0[1-9]|1[012])\2(0[1-9]|[12][0-9]|3[01])$/g;
            var regDMY = /^(0[1-9]|[12][0-9]|3[01])[- /.](0[1-9]|1[012])[- /.](19|20)\d\d$/g;
            valid = (regYMD.test(controlValue) || regDMY.test(controlValue));
        }
        return valid ? Validators.nullValidator : { 'dateValidator': { value: controlValue } };
    };
}
//# sourceMappingURL=date-validator.directive.js.map