// Copyright (c) 2017 VMware, Inc. All Rights Reserved.
//
// Licensed under the Apache License, Version 2.0 (the "License");
// you may not use this file except in compliance with the License.
// You may obtain a copy of the License at
//
//    http://www.apache.org/licenses/LICENSE-2.0
//
// Unless required by applicable law or agreed to in writing, software
// distributed under the License is distributed on an "AS IS" BASIS,
// WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
// See the License for the specific language governing permissions and
// limitations under the License.
import { Component, Input, Output, EventEmitter } from '@angular/core';
import { Subject } from 'rxjs/Subject';
import 'rxjs/add/operator/debounceTime';
import 'rxjs/add/operator/distinctUntilChanged';
import { FILTER_TEMPLATE, FILTER_STYLES } from './filter.template';
var FilterComponent = (function () {
    function FilterComponent() {
        this.placeHolder = "";
        this.filterTerms = new Subject();
        this.isExpanded = false;
        this.filterEvt = new EventEmitter();
        this.expandMode = false;
        this.withDivider = false;
    }
    Object.defineProperty(FilterComponent.prototype, "flPlaceholder", {
        set: function (placeHolder) {
            this.placeHolder = placeHolder;
        },
        enumerable: true,
        configurable: true
    });
    FilterComponent.prototype.ngOnInit = function () {
        var _this = this;
        this.filterTerms
            .debounceTime(500)
            .subscribe(function (terms) {
            _this.filterEvt.emit(terms);
        });
    };
    FilterComponent.prototype.valueChange = function () {
        //Send out filter terms
        this.filterTerms.next(this.currentValue.trim());
    };
    FilterComponent.prototype.onClick = function () {
        //Only enabled when expandMode is set to false
        if (this.expandMode) {
            return;
        }
        this.isExpanded = !this.isExpanded;
    };
    Object.defineProperty(FilterComponent.prototype, "isShowSearchBox", {
        get: function () {
            return this.expandMode || (!this.expandMode && this.isExpanded);
        },
        enumerable: true,
        configurable: true
    });
    return FilterComponent;
}());
export { FilterComponent };
FilterComponent.decorators = [
    { type: Component, args: [{
                selector: 'hbr-filter',
                styles: [FILTER_STYLES],
                template: FILTER_TEMPLATE
            },] },
];
/** @nocollapse */
FilterComponent.ctorParameters = function () { return []; };
FilterComponent.propDecorators = {
    'filterEvt': [{ type: Output, args: ["filter",] },],
    'currentValue': [{ type: Input },],
    'flPlaceholder': [{ type: Input, args: ["filterPlaceholder",] },],
    'expandMode': [{ type: Input },],
    'withDivider': [{ type: Input },],
};
//# sourceMappingURL=filter.component.js.map