import { Injectable } from "@angular/core";
import { TranslateService } from '@ngx-translate/core';
import { DEFAULT_LANG_COOKIE_KEY, DEFAULT_SUPPORTING_LANGS, DEFAULT_LANG } from '../utils';
import { CookieService } from 'ngx-cookie';
var TranslateServiceInitializer = (function () {
    function TranslateServiceInitializer(translateService, cookie) {
        this.translateService = translateService;
        this.cookie = cookie;
    }
    TranslateServiceInitializer.prototype.init = function (config) {
        if (config === void 0) { config = {}; }
        var selectedLang = config.defaultLang ? config.defaultLang : DEFAULT_LANG;
        var supportedLangs = config.supportedLangs ? config.supportedLangs : DEFAULT_SUPPORTING_LANGS;
        this.translateService.addLangs(supportedLangs);
        this.translateService.setDefaultLang(selectedLang);
        if (config.enablei18Support) {
            //If user has selected lang, then directly use it
            var langSetting_1 = this.cookie.get(config.langCookieKey ? config.langCookieKey : DEFAULT_LANG_COOKIE_KEY);
            if (!langSetting_1 || langSetting_1.trim() === "") {
                //Use browser lang
                langSetting_1 = this.translateService.getBrowserCultureLang().toLowerCase();
            }
            if (langSetting_1 && langSetting_1.trim() !== "") {
                if (supportedLangs && supportedLangs.length > 0) {
                    if (supportedLangs.find(function (lang) { return lang === langSetting_1; })) {
                        selectedLang = langSetting_1;
                    }
                }
            }
        }
        this.translateService.use(selectedLang);
    };
    return TranslateServiceInitializer;
}());
export { TranslateServiceInitializer };
TranslateServiceInitializer.decorators = [
    { type: Injectable },
];
/** @nocollapse */
TranslateServiceInitializer.ctorParameters = function () { return [
    { type: TranslateService, },
    { type: CookieService, },
]; };
//# sourceMappingURL=translate-init.service.js.map