// Copyright (c) 2017 VMware, Inc. All Rights Reserved.
//
// Licensed under the Apache License, Version 2.0 (the "License");
// you may not use this file except in compliance with the License.
// You may obtain a copy of the License at
//
//    http://www.apache.org/licenses/LICENSE-2.0
//
// Unless required by applicable law or agreed to in writing, software
// distributed under the License is distributed on an "AS IS" BASIS,
// WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
// See the License for the specific language governing permissions and
// limitations under the License.
import { Component, Output, EventEmitter } from '@angular/core';
import { TranslateService } from '@ngx-translate/core';
import { errorHandler } from '../shared/shared.utils';
import { INLINE_ALERT_STYLE } from './inline-alert.component.css';
import { INLINE_ALERT_TEMPLATE } from './inline-alert.component.html';
var InlineAlertComponent = (function () {
    function InlineAlertComponent(translate) {
        this.translate = translate;
        this.inlineAlertType = 'alert-danger';
        this.inlineAlertClosable = false;
        this.alertClose = true;
        this.displayedText = "";
        this.showCancelAction = false;
        this.useAppLevelStyle = false;
        this.timer = null;
        this.count = 0;
        this.blinking = false;
        this.confirmEvt = new EventEmitter();
    }
    Object.defineProperty(InlineAlertComponent.prototype, "errorMessage", {
        get: function () {
            return this.displayedText;
        },
        enumerable: true,
        configurable: true
    });
    //Show error message inline
    InlineAlertComponent.prototype.showInlineError = function (error) {
        var _this = this;
        this.displayedText = errorHandler(error);
        if (this.displayedText) {
            this.translate.get(this.displayedText).subscribe(function (res) { return _this.displayedText = res; });
        }
        this.inlineAlertType = 'alert-danger';
        this.showCancelAction = false;
        this.inlineAlertClosable = true;
        this.alertClose = false;
        this.useAppLevelStyle = false;
    };
    //Show confirmation info with action button
    InlineAlertComponent.prototype.showInlineConfirmation = function (warning) {
        var _this = this;
        this.displayedText = "";
        if (warning && warning.message) {
            this.translate.get(warning.message).subscribe(function (res) { return _this.displayedText = res; });
        }
        this.inlineAlertType = 'alert-warning';
        this.showCancelAction = true;
        this.inlineAlertClosable = false;
        this.alertClose = false;
        this.useAppLevelStyle = false;
    };
    //Show inline sccess info
    InlineAlertComponent.prototype.showInlineSuccess = function (info) {
        var _this = this;
        this.displayedText = "";
        if (info && info.message) {
            this.translate.get(info.message).subscribe(function (res) { return _this.displayedText = res; });
        }
        this.inlineAlertType = 'alert-success';
        this.showCancelAction = false;
        this.inlineAlertClosable = true;
        this.alertClose = false;
        this.useAppLevelStyle = false;
    };
    //Close alert
    InlineAlertComponent.prototype.close = function () {
        this.alertClose = true;
    };
    InlineAlertComponent.prototype.blink = function () {
    };
    InlineAlertComponent.prototype.confirmCancel = function () {
        this.confirmEvt.emit(true);
    };
    return InlineAlertComponent;
}());
export { InlineAlertComponent };
InlineAlertComponent.decorators = [
    { type: Component, args: [{
                selector: 'hbr-inline-alert',
                template: INLINE_ALERT_TEMPLATE,
                styles: [INLINE_ALERT_STYLE]
            },] },
];
/** @nocollapse */
InlineAlertComponent.ctorParameters = function () { return [
    { type: TranslateService, },
]; };
InlineAlertComponent.propDecorators = {
    'confirmEvt': [{ type: Output },],
};
//# sourceMappingURL=inline-alert.component.js.map