// Copyright (c) 2017 VMware, Inc. All Rights Reserved.
//
// Licensed under the Apache License, Version 2.0 (the "License");
// you may not use this file except in compliance with the License.
// You may obtain a copy of the License at
//
//    http://www.apache.org/licenses/LICENSE-2.0
//
// Unless required by applicable law or agreed to in writing, software
// distributed under the License is distributed on an "AS IS" BASIS,
// WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
// See the License for the specific language governing permissions and
// limitations under the License.
import { ChangeDetectionStrategy, ChangeDetectorRef, Component, Input } from '@angular/core';
import { JOB_LOG_VIEWER_TEMPLATE, JOB_LOG_VIEWER_STYLES } from './job-log-viewer.component.template';
import { JobLogService } from '../service/index';
import { ErrorHandler } from '../error-handler/index';
import { toPromise } from '../utils';
var supportSet = ["replication", "scan"];
var JobLogViewerComponent = (function () {
    function JobLogViewerComponent(jobLogService, errorHandler, ref) {
        this.jobLogService = jobLogService;
        this.errorHandler = errorHandler;
        this.ref = ref;
        this._jobType = "replication";
        this.opened = false;
        this.log = '';
        this.onGoing = true;
    }
    Object.defineProperty(JobLogViewerComponent.prototype, "jobType", {
        get: function () {
            return this._jobType;
        },
        set: function (v) {
            if (supportSet.find(function (t) { return t === v; })) {
                this._jobType = v;
            }
        },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(JobLogViewerComponent.prototype, "title", {
        get: function () {
            if (this.jobType === "scan") {
                return "VULNERABILITY.JOB_LOG_VIEWER";
            }
            return "REPLICATION.JOB_LOG_VIEWER";
        },
        enumerable: true,
        configurable: true
    });
    JobLogViewerComponent.prototype.open = function (jobId) {
        this.opened = true;
        this.load(jobId);
    };
    JobLogViewerComponent.prototype.close = function () {
        this.opened = false;
        this.log = "";
    };
    JobLogViewerComponent.prototype.load = function (jobId) {
        var _this = this;
        this.onGoing = true;
        toPromise(this.jobLogService.getJobLog(this.jobType, jobId))
            .then(function (log) {
            _this.onGoing = false;
            _this.log = log;
        })
            .catch(function (error) {
            _this.onGoing = false;
            _this.errorHandler.error(error);
        });
        var hnd = setInterval(function () { return _this.ref.markForCheck(); }, 100);
        setTimeout(function () { return clearInterval(hnd); }, 2000);
    };
    return JobLogViewerComponent;
}());
export { JobLogViewerComponent };
JobLogViewerComponent.decorators = [
    { type: Component, args: [{
                selector: 'job-log-viewer',
                template: JOB_LOG_VIEWER_TEMPLATE,
                styles: [JOB_LOG_VIEWER_STYLES],
                changeDetection: ChangeDetectionStrategy.OnPush
            },] },
];
/** @nocollapse */
JobLogViewerComponent.ctorParameters = function () { return [
    { type: JobLogService, },
    { type: ErrorHandler, },
    { type: ChangeDetectorRef, },
]; };
JobLogViewerComponent.propDecorators = {
    'jobType': [{ type: Input },],
};
//# sourceMappingURL=job-log-viewer.component.js.map