import { Component, Input, ViewChild } from '@angular/core';
import { PROJECT_POLICY_CONFIG_TEMPLATE } from './project-policy-config.component.html';
import { PROJECT_POLICY_CONFIG_STYLE } from './project-policy-config.component.css';
import { toPromise, compareValue, clone } from '../utils';
import { ProjectService } from '../service/project.service';
import { ErrorHandler } from '../error-handler/error-handler';
import { ConfirmationMessage } from '../confirmation-dialog/confirmation-message';
import { TranslateService } from '@ngx-translate/core';
import { SystemInfoService } from '../service/index';
var ProjectPolicy = (function () {
    function ProjectPolicy() {
        this.Public = false;
        this.ContentTrust = false;
        this.PreventVulImg = false;
        this.PreventVulImgSeverity = 'low';
        this.ScanImgOnPush = false;
    }
    ProjectPolicy.prototype.initByProject = function (pro) {
        this.Public = pro.metadata.public === 'true' ? true : false;
        this.ContentTrust = pro.metadata.enable_content_trust === 'true' ? true : false;
        this.PreventVulImg = pro.metadata.prevent_vul === 'true' ? true : false;
        if (pro.metadata.severity) {
            this.PreventVulImgSeverity = pro.metadata.severity;
        }
        ;
        this.ScanImgOnPush = pro.metadata.auto_scan === 'true' ? true : false;
    };
    ;
    return ProjectPolicy;
}());
export { ProjectPolicy };
var ProjectPolicyConfigComponent = (function () {
    function ProjectPolicyConfigComponent(errorHandler, translate, projectService, systemInfoService) {
        this.errorHandler = errorHandler;
        this.translate = translate;
        this.projectService = projectService;
        this.systemInfoService = systemInfoService;
        this.onGoing = false;
        this.projectName = 'unknown';
        this.orgProjectPolicy = new ProjectPolicy();
        this.projectPolicy = new ProjectPolicy();
        this.severityOptions = [
            { severity: 'high', severityLevel: 'VULNERABILITY.SEVERITY.HIGH' },
            { severity: 'medium', severityLevel: 'VULNERABILITY.SEVERITY.MEDIUM' },
            { severity: 'low', severityLevel: 'VULNERABILITY.SEVERITY.LOW' },
            { severity: 'negligible', severityLevel: 'VULNERABILITY.SEVERITY.NEGLIGIBLE' },
        ];
    }
    ProjectPolicyConfigComponent.prototype.ngOnInit = function () {
        var _this = this;
        // assert if project id exist
        if (!this.projectId) {
            this.errorHandler.error('Project ID cannot be unset.');
            return;
        }
        // get system info
        toPromise(this.systemInfoService.getSystemInfo())
            .then(function (systemInfo) { return _this.systemInfo = systemInfo; })
            .catch(function (error) { return _this.errorHandler.error(error); });
        // retrive project level policy data
        this.retrieve();
    };
    Object.defineProperty(ProjectPolicyConfigComponent.prototype, "withNotary", {
        get: function () {
            return this.systemInfo ? this.systemInfo.with_notary : false;
        },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(ProjectPolicyConfigComponent.prototype, "withClair", {
        get: function () {
            return this.systemInfo ? this.systemInfo.with_clair : false;
        },
        enumerable: true,
        configurable: true
    });
    ProjectPolicyConfigComponent.prototype.retrieve = function (state) {
        var _this = this;
        toPromise(this.projectService.getProject(this.projectId))
            .then(function (response) {
            _this.orgProjectPolicy.initByProject(response);
            _this.projectPolicy.initByProject(response);
        })
            .catch(function (error) { return _this.errorHandler.error(error); });
    };
    ProjectPolicyConfigComponent.prototype.updateProjectPolicy = function (projectId, pp) {
        this.projectService.updateProjectPolicy(projectId, pp);
    };
    ProjectPolicyConfigComponent.prototype.refresh = function () {
        this.retrieve();
    };
    ProjectPolicyConfigComponent.prototype.isValid = function () {
        var _this = this;
        var flag = false;
        if (!this.projectPolicy.PreventVulImg || this.severityOptions.some(function (x) { return x.severity === _this.projectPolicy.PreventVulImgSeverity; })) {
            flag = true;
        }
        return flag;
    };
    ProjectPolicyConfigComponent.prototype.hasChanges = function () {
        return !compareValue(this.orgProjectPolicy, this.projectPolicy);
    };
    ProjectPolicyConfigComponent.prototype.save = function () {
        var _this = this;
        if (!this.hasChanges()) {
            return;
        }
        this.onGoing = true;
        toPromise(this.projectService.updateProjectPolicy(this.projectId, this.projectPolicy))
            .then(function () {
            _this.onGoing = false;
            _this.translate.get('CONFIG.SAVE_SUCCESS').subscribe(function (res) {
                _this.errorHandler.info(res);
            });
            _this.refresh();
        })
            .catch(function (error) {
            _this.onGoing = false;
            _this.errorHandler.error(error);
        });
    };
    ProjectPolicyConfigComponent.prototype.cancel = function () {
        var msg = new ConfirmationMessage('CONFIG.CONFIRM_TITLE', 'CONFIG.CONFIRM_SUMMARY', '', {}, 9 /* CONFIG */);
        this.confirmationDlg.open(msg);
    };
    ProjectPolicyConfigComponent.prototype.reset = function () {
        this.projectPolicy = clone(this.orgProjectPolicy);
    };
    ProjectPolicyConfigComponent.prototype.confirmCancel = function (ack) {
        if (ack && ack.source === 9 /* CONFIG */ &&
            ack.state === 1 /* CONFIRMED */) {
            this.reset();
        }
    };
    return ProjectPolicyConfigComponent;
}());
export { ProjectPolicyConfigComponent };
ProjectPolicyConfigComponent.decorators = [
    { type: Component, args: [{
                selector: 'hbr-project-policy-config',
                template: PROJECT_POLICY_CONFIG_TEMPLATE,
                styles: [PROJECT_POLICY_CONFIG_STYLE],
            },] },
];
/** @nocollapse */
ProjectPolicyConfigComponent.ctorParameters = function () { return [
    { type: ErrorHandler, },
    { type: TranslateService, },
    { type: ProjectService, },
    { type: SystemInfoService, },
]; };
ProjectPolicyConfigComponent.propDecorators = {
    'projectId': [{ type: Input },],
    'projectName': [{ type: Input },],
    'hasSignedIn': [{ type: Input },],
    'hasProjectAdminRole': [{ type: Input },],
    'confirmationDlg': [{ type: ViewChild, args: ['cfgConfirmationDialog',] },],
};
//# sourceMappingURL=project-policy-config.component.js.map