var __extends = (this && this.__extends) || (function () {
    var extendStatics = Object.setPrototypeOf ||
        ({ __proto__: [] } instanceof Array && function (d, b) { d.__proto__ = b; }) ||
        function (d, b) { for (var p in b) if (b.hasOwnProperty(p)) d[p] = b[p]; };
    return function (d, b) {
        extendStatics(d, b);
        function __() { this.constructor = d; }
        d.prototype = b === null ? Object.create(b) : (__.prototype = b.prototype, new __());
    };
})();
import { RequestQueryParams } from './RequestQueryParams';
import { Injectable, Inject } from "@angular/core";
import { Http } from '@angular/http';
import 'rxjs/add/observable/of';
import { SERVICE_CONFIG } from '../service.config';
import { buildHttpRequestOptions, HTTP_JSON_OPTIONS, HTTP_GET_OPTIONS } from '../utils';
/**
 * Define the service methods to handle the endpoint related things.
 *
 * @export
 * @abstract
 * @class EndpointService
 */
var EndpointService = (function () {
    function EndpointService() {
    }
    return EndpointService;
}());
export { EndpointService };
/**
 * Implement default service for endpoint.
 *
 * @export
 * @class EndpointDefaultService
 * @extends {EndpointService}
 */
var EndpointDefaultService = (function (_super) {
    __extends(EndpointDefaultService, _super);
    function EndpointDefaultService(config, http) {
        var _this = _super.call(this) || this;
        _this.http = http;
        _this._endpointUrl = config.targetBaseEndpoint ? config.targetBaseEndpoint : '/api/targets';
        return _this;
    }
    EndpointDefaultService.prototype.getEndpoints = function (endpointName, queryParams) {
        if (!queryParams) {
            queryParams = new RequestQueryParams();
        }
        if (endpointName) {
            queryParams.set('name', endpointName);
        }
        var requestUrl = "" + this._endpointUrl;
        return this.http
            .get(requestUrl, buildHttpRequestOptions(queryParams))
            .toPromise()
            .then(function (response) { return response.json(); })
            .catch(function (error) { return Promise.reject(error); });
    };
    EndpointDefaultService.prototype.getEndpoint = function (endpointId) {
        if (!endpointId || endpointId <= 0) {
            return Promise.reject('Bad request argument.');
        }
        var requestUrl = this._endpointUrl + "/" + endpointId;
        return this.http
            .get(requestUrl, HTTP_GET_OPTIONS)
            .toPromise()
            .then(function (response) { return response.json(); })
            .catch(function (error) { return Promise.reject(error); });
    };
    EndpointDefaultService.prototype.createEndpoint = function (endpoint) {
        if (!endpoint) {
            return Promise.reject('Invalid endpoint.');
        }
        var requestUrl = "" + this._endpointUrl;
        return this.http
            .post(requestUrl, JSON.stringify(endpoint), HTTP_JSON_OPTIONS)
            .toPromise()
            .then(function (response) { return response.status; })
            .catch(function (error) { return Promise.reject(error); });
    };
    EndpointDefaultService.prototype.updateEndpoint = function (endpointId, endpoint) {
        if (!endpointId || endpointId <= 0) {
            return Promise.reject('Bad request argument.');
        }
        if (!endpoint) {
            return Promise.reject('Invalid endpoint.');
        }
        var requestUrl = this._endpointUrl + "/" + endpointId;
        return this.http
            .put(requestUrl, JSON.stringify(endpoint), HTTP_JSON_OPTIONS)
            .toPromise()
            .then(function (response) { return response.status; })
            .catch(function (error) { return Promise.reject(error); });
    };
    EndpointDefaultService.prototype.deleteEndpoint = function (endpointId) {
        if (!endpointId || endpointId <= 0) {
            return Promise.reject('Bad request argument.');
        }
        var requestUrl = this._endpointUrl + "/" + endpointId;
        return this.http
            .delete(requestUrl)
            .toPromise()
            .then(function (response) { return response.status; })
            .catch(function (error) { return Promise.reject(error); });
    };
    EndpointDefaultService.prototype.pingEndpoint = function (endpoint) {
        if (!endpoint) {
            return Promise.reject('Invalid endpoint.');
        }
        var requestUrl = this._endpointUrl + "/ping";
        return this.http
            .post(requestUrl, endpoint, HTTP_JSON_OPTIONS)
            .toPromise()
            .then(function (response) { return response.status; })
            .catch(function (error) { return Promise.reject(error); });
    };
    EndpointDefaultService.prototype.getEndpointWithReplicationRules = function (endpointId) {
        if (!endpointId || endpointId <= 0) {
            return Promise.reject('Bad request argument.');
        }
        var requestUrl = this._endpointUrl + "/" + endpointId + "/policies";
        return this.http
            .get(requestUrl, HTTP_GET_OPTIONS)
            .toPromise()
            .then(function (response) { return response.json(); })
            .catch(function (error) { return Promise.reject(error); });
    };
    return EndpointDefaultService;
}(EndpointService));
export { EndpointDefaultService };
EndpointDefaultService.decorators = [
    { type: Injectable },
];
/** @nocollapse */
EndpointDefaultService.ctorParameters = function () { return [
    { type: undefined, decorators: [{ type: Inject, args: [SERVICE_CONFIG,] },] },
    { type: Http, },
]; };
//# sourceMappingURL=endpoint.service.js.map