var __extends = (this && this.__extends) || (function () {
    var extendStatics = Object.setPrototypeOf ||
        ({ __proto__: [] } instanceof Array && function (d, b) { d.__proto__ = b; }) ||
        function (d, b) { for (var p in b) if (b.hasOwnProperty(p)) d[p] = b[p]; };
    return function (d, b) {
        extendStatics(d, b);
        function __() { this.constructor = d; }
        d.prototype = b === null ? Object.create(b) : (__.prototype = b.prototype, new __());
    };
})();
import { Observable } from 'rxjs/Observable';
import { Injectable, Inject } from '@angular/core';
import { Http } from '@angular/http';
import 'rxjs/add/observable/of';
import { SERVICE_CONFIG } from '../service.config';
import { HTTP_JSON_OPTIONS, HTTP_GET_OPTIONS, buildHttpRequestOptions } from "../utils";
import { RequestQueryParams } from "./RequestQueryParams";
/**
 * Define the service methods to handle the Prject related things.
 *
 * @export
 * @abstract
 * @class ProjectService
 */
var ProjectService = (function () {
    function ProjectService() {
    }
    return ProjectService;
}());
export { ProjectService };
/**
 * Implement default service for project.
 *
 * @export
 * @class ProjectDefaultService
 * @extends {ProjectService}
 */
var ProjectDefaultService = (function (_super) {
    __extends(ProjectDefaultService, _super);
    function ProjectDefaultService(http, config) {
        var _this = _super.call(this) || this;
        _this.http = http;
        _this.config = config;
        return _this;
    }
    ProjectDefaultService.prototype.getProject = function (projectId) {
        if (!projectId) {
            return Promise.reject('Bad argument');
        }
        var baseUrl = this.config.projectBaseEndpoint ? this.config.projectBaseEndpoint : '/api/projects';
        return this.http
            .get(baseUrl + "/" + projectId, HTTP_GET_OPTIONS)
            .map(function (response) { return response.json(); })
            .catch(function (error) { return Observable.throw(error); });
    };
    ProjectDefaultService.prototype.listProjects = function (name, isPublic, page, pageSize) {
        var baseUrl = this.config.projectBaseEndpoint ? this.config.projectBaseEndpoint : '/api/projects';
        var params = new RequestQueryParams();
        if (page && pageSize) {
            params.set('page', page + '');
            params.set('page_size', pageSize + '');
        }
        if (name && name.trim() !== "") {
            params.set('name', name);
        }
        if (isPublic !== undefined) {
            params.set('public', '' + isPublic);
        }
        // let options = new RequestOptions({ headers: this.getHeaders, search: params });
        return this.http
            .get(baseUrl, buildHttpRequestOptions(params))
            .map(function (response) { return response.json(); })
            .catch(function (error) { return Observable.throw(error); });
    };
    ProjectDefaultService.prototype.updateProjectPolicy = function (projectId, projectPolicy) {
        var baseUrl = this.config.projectBaseEndpoint ? this.config.projectBaseEndpoint : '/api/projects';
        return this.http
            .put(baseUrl + "/" + projectId, {
            'metadata': {
                'public': projectPolicy.Public ? 'true' : 'false',
                'enable_content_trust': projectPolicy.ContentTrust ? 'true' : 'false',
                'prevent_vul': projectPolicy.PreventVulImg ? 'true' : 'false',
                'severity': projectPolicy.PreventVulImgSeverity,
                'auto_scan': projectPolicy.ScanImgOnPush ? 'true' : 'false'
            }
        }, HTTP_JSON_OPTIONS)
            .map(function (response) { return response.status; })
            .catch(function (error) { return Observable.throw(error); });
    };
    return ProjectDefaultService;
}(ProjectService));
export { ProjectDefaultService };
ProjectDefaultService.decorators = [
    { type: Injectable },
];
/** @nocollapse */
ProjectDefaultService.ctorParameters = function () { return [
    { type: Http, },
    { type: undefined, decorators: [{ type: Inject, args: [SERVICE_CONFIG,] },] },
]; };
//# sourceMappingURL=project.service.js.map