var __extends = (this && this.__extends) || (function () {
    var extendStatics = Object.setPrototypeOf ||
        ({ __proto__: [] } instanceof Array && function (d, b) { d.__proto__ = b; }) ||
        function (d, b) { for (var p in b) if (b.hasOwnProperty(p)) d[p] = b[p]; };
    return function (d, b) {
        extendStatics(d, b);
        function __() { this.constructor = d; }
        d.prototype = b === null ? Object.create(b) : (__.prototype = b.prototype, new __());
    };
})();
import { RequestQueryParams } from './RequestQueryParams';
import { Injectable, Inject } from "@angular/core";
import 'rxjs/add/observable/of';
import { Http } from '@angular/http';
import { SERVICE_CONFIG } from '../service.config';
import { buildHttpRequestOptions, HTTP_JSON_OPTIONS, HTTP_GET_OPTIONS } from '../utils';
/**
 * Define the service methods to handle the replication (rule and job) related things.
 *
 * @export
 * @abstract
 * @class ReplicationService
 */
var ReplicationService = (function () {
    function ReplicationService() {
    }
    return ReplicationService;
}());
export { ReplicationService };
/**
 * Implement default service for replication rule and job.
 *
 * @export
 * @class ReplicationDefaultService
 * @extends {ReplicationService}
 */
var ReplicationDefaultService = (function (_super) {
    __extends(ReplicationDefaultService, _super);
    function ReplicationDefaultService(http, config) {
        var _this = _super.call(this) || this;
        _this.http = http;
        _this._ruleBaseUrl = config.replicationRuleEndpoint ? config.replicationRuleEndpoint : '/api/policies/replication';
        _this._jobBaseUrl = config.replicationJobEndpoint ? config.replicationJobEndpoint : '/api/jobs/replication';
        _this._replicateUrl = config.replicationBaseEndpoint ? config.replicationBaseEndpoint : '/api/replications';
        return _this;
    }
    //Private methods
    //Check if the rule object is valid
    ReplicationDefaultService.prototype._isValidRule = function (rule) {
        return rule !== undefined && rule != null && rule.name !== undefined && rule.name.trim() !== '' && rule.targets.length !== 0;
    };
    ReplicationDefaultService.prototype.getReplicationRules = function (projectId, ruleName, queryParams) {
        if (!queryParams) {
            queryParams = new RequestQueryParams();
        }
        if (projectId) {
            queryParams.set('project_id', '' + projectId);
        }
        if (ruleName) {
            queryParams.set('name', ruleName);
        }
        return this.http.get(this._ruleBaseUrl, buildHttpRequestOptions(queryParams)).toPromise()
            .then(function (response) { return response.json(); })
            .catch(function (error) { return Promise.reject(error); });
    };
    ReplicationDefaultService.prototype.getReplicationRule = function (ruleId) {
        if (!ruleId) {
            return Promise.reject("Bad argument");
        }
        var url = this._ruleBaseUrl + "/" + ruleId;
        return this.http.get(url, HTTP_GET_OPTIONS).toPromise()
            .then(function (response) { return response.json(); })
            .catch(function (error) { return Promise.reject(error); });
    };
    ReplicationDefaultService.prototype.createReplicationRule = function (replicationRule) {
        if (!this._isValidRule(replicationRule)) {
            return Promise.reject('Bad argument');
        }
        return this.http.post(this._ruleBaseUrl, JSON.stringify(replicationRule), HTTP_JSON_OPTIONS).toPromise()
            .then(function (response) { return response; })
            .catch(function (error) { return Promise.reject(error); });
    };
    ReplicationDefaultService.prototype.updateReplicationRule = function (id, rep) {
        if (!this._isValidRule(rep)) {
            return Promise.reject('Bad argument');
        }
        var url = this._ruleBaseUrl + "/" + id;
        return this.http.put(url, JSON.stringify(rep), HTTP_JSON_OPTIONS).toPromise()
            .then(function (response) { return response; })
            .catch(function (error) { return Promise.reject(error); });
    };
    ReplicationDefaultService.prototype.deleteReplicationRule = function (ruleId) {
        if (!ruleId || ruleId <= 0) {
            return Promise.reject('Bad argument');
        }
        var url = this._ruleBaseUrl + "/" + ruleId;
        return this.http.delete(url, HTTP_JSON_OPTIONS).toPromise()
            .then(function (response) { return response; })
            .catch(function (error) { return Promise.reject(error); });
    };
    ReplicationDefaultService.prototype.replicateRule = function (ruleId) {
        if (!ruleId) {
            return Promise.reject("Bad argument");
        }
        var url = "" + this._replicateUrl;
        return this.http.post(url, { policy_id: ruleId }, HTTP_JSON_OPTIONS).toPromise()
            .then(function (response) { return response; })
            .catch(function (error) { return Promise.reject(error); });
    };
    ReplicationDefaultService.prototype.enableReplicationRule = function (ruleId, enablement) {
        if (!ruleId || ruleId <= 0) {
            return Promise.reject('Bad argument');
        }
        var url = this._ruleBaseUrl + "/" + ruleId + "/enablement";
        return this.http.put(url, { enabled: enablement }, HTTP_JSON_OPTIONS).toPromise()
            .then(function (response) { return response; })
            .catch(function (error) { return Promise.reject(error); });
    };
    ReplicationDefaultService.prototype.disableReplicationRule = function (ruleId) {
        if (!ruleId || ruleId <= 0) {
            return Promise.reject('Bad argument');
        }
        var url = this._ruleBaseUrl + "/" + ruleId + "/enablement";
        return this.http.put(url, { enabled: 0 }, HTTP_JSON_OPTIONS).toPromise()
            .then(function (response) { return response; })
            .catch(function (error) { return Promise.reject(error); });
    };
    ReplicationDefaultService.prototype.getJobs = function (ruleId, queryParams) {
        if (!ruleId || ruleId <= 0) {
            return Promise.reject('Bad argument');
        }
        if (!queryParams) {
            queryParams = new RequestQueryParams();
        }
        queryParams.set('policy_id', '' + ruleId);
        return this.http.get(this._jobBaseUrl, buildHttpRequestOptions(queryParams)).toPromise()
            .then(function (response) {
            var result = {
                metadata: {
                    xTotalCount: 0
                },
                data: []
            };
            if (response && response.headers) {
                var xHeader = response.headers.get("X-Total-Count");
                if (xHeader) {
                    result.metadata.xTotalCount = parseInt(xHeader, 0);
                }
            }
            result.data = response.json();
            if (result.metadata.xTotalCount === 0) {
                if (result.data && result.data.length > 0) {
                    result.metadata.xTotalCount = result.data.length;
                }
            }
            return result;
        })
            .catch(function (error) { return Promise.reject(error); });
    };
    ReplicationDefaultService.prototype.getJobLog = function (jobId) {
        if (!jobId || jobId <= 0) {
            return Promise.reject('Bad argument');
        }
        var logUrl = this._jobBaseUrl + "/" + jobId + "/log";
        return this.http.get(logUrl, HTTP_GET_OPTIONS).toPromise()
            .then(function (response) { return response.text(); })
            .catch(function (error) { return Promise.reject(error); });
    };
    ReplicationDefaultService.prototype.stopJobs = function (jobId) {
        return this.http.put(this._jobBaseUrl, JSON.stringify({ 'policy_id': jobId, 'status': 'stop' }), HTTP_JSON_OPTIONS).toPromise()
            .then(function (response) { return response; })
            .catch(function (error) { return Promise.reject(error); });
    };
    return ReplicationDefaultService;
}(ReplicationService));
export { ReplicationDefaultService };
ReplicationDefaultService.decorators = [
    { type: Injectable },
];
/** @nocollapse */
ReplicationDefaultService.ctorParameters = function () { return [
    { type: Http, },
    { type: undefined, decorators: [{ type: Inject, args: [SERVICE_CONFIG,] },] },
]; };
//# sourceMappingURL=replication.service.js.map