var __extends = (this && this.__extends) || (function () {
    var extendStatics = Object.setPrototypeOf ||
        ({ __proto__: [] } instanceof Array && function (d, b) { d.__proto__ = b; }) ||
        function (d, b) { for (var p in b) if (b.hasOwnProperty(p)) d[p] = b[p]; };
    return function (d, b) {
        extendStatics(d, b);
        function __() { this.constructor = d; }
        d.prototype = b === null ? Object.create(b) : (__.prototype = b.prototype, new __());
    };
})();
import { RequestQueryParams } from './RequestQueryParams';
import { Injectable, Inject } from '@angular/core';
import 'rxjs/add/observable/of';
import { Http } from '@angular/http';
import { SERVICE_CONFIG } from '../service.config';
import { buildHttpRequestOptions, HTTP_JSON_OPTIONS } from '../utils';
/**
 * Define service methods for handling the repository related things.
 * Loose couple with project module.
 *
 * @export
 * @abstract
 * @class RepositoryService
 */
var RepositoryService = (function () {
    function RepositoryService() {
    }
    return RepositoryService;
}());
export { RepositoryService };
/**
 * Implement default service for repository.
 *
 * @export
 * @class RepositoryDefaultService
 * @extends {RepositoryService}
 */
var RepositoryDefaultService = (function (_super) {
    __extends(RepositoryDefaultService, _super);
    function RepositoryDefaultService(http, config) {
        var _this = _super.call(this) || this;
        _this.http = http;
        _this.config = config;
        return _this;
    }
    RepositoryDefaultService.prototype.getRepositories = function (projectId, repositoryName, queryParams) {
        if (!projectId) {
            return Promise.reject('Bad argument');
        }
        if (!queryParams) {
            queryParams = new RequestQueryParams();
        }
        queryParams.set('project_id', '' + projectId);
        if (repositoryName && repositoryName.trim() !== '') {
            queryParams.set('q', repositoryName);
        }
        var url = this.config.repositoryBaseEndpoint ? this.config.repositoryBaseEndpoint : '/api/repositories';
        return this.http.get(url, buildHttpRequestOptions(queryParams)).toPromise()
            .then(function (response) {
            var result = {
                metadata: { xTotalCount: 0 },
                data: []
            };
            if (response && response.headers) {
                var xHeader = response.headers.get('X-Total-Count');
                if (xHeader) {
                    result.metadata.xTotalCount = parseInt(xHeader, 0);
                }
            }
            result.data = response.json();
            if (result.metadata.xTotalCount === 0) {
                if (result.data && result.data.length > 0) {
                    result.metadata.xTotalCount = result.data.length;
                }
            }
            return result;
        })
            .catch(function (error) { return Promise.reject(error); });
    };
    RepositoryDefaultService.prototype.updateRepositoryDescription = function (repositoryName, description, queryParams) {
        if (!queryParams) {
            queryParams = new RequestQueryParams();
        }
        var baseUrl = this.config.repositoryBaseEndpoint ? this.config.repositoryBaseEndpoint : '/api/repositories';
        var url = baseUrl + "/" + repositoryName;
        return this.http.put(url, { 'description': description }, HTTP_JSON_OPTIONS).toPromise()
            .then(function (response) { return response; })
            .catch(function (error) { return Promise.reject(error); });
    };
    RepositoryDefaultService.prototype.deleteRepository = function (repositoryName) {
        if (!repositoryName) {
            return Promise.reject('Bad argument');
        }
        var url = this.config.repositoryBaseEndpoint ? this.config.repositoryBaseEndpoint : '/api/repositories';
        url = url + "/" + repositoryName;
        return this.http.delete(url, HTTP_JSON_OPTIONS).toPromise()
            .then(function (response) { return response; })
            .catch(function (error) { return Promise.reject(error); });
    };
    return RepositoryDefaultService;
}(RepositoryService));
export { RepositoryDefaultService };
RepositoryDefaultService.decorators = [
    { type: Injectable },
];
/** @nocollapse */
RepositoryDefaultService.ctorParameters = function () { return [
    { type: Http, },
    { type: undefined, decorators: [{ type: Inject, args: [SERVICE_CONFIG,] },] },
]; };
//# sourceMappingURL=repository.service.js.map