/**
 * To handle the error message body
 *
 * @export
 * @returns {string}
 */
export var errorHandler = function (error) {
    if (!error) {
        return "UNKNOWN_ERROR";
    }
    if (!(error.statusCode || error.status)) {
        // treat as string message
        return '' + error;
    }
    else {
        switch (error.statusCode || error.status) {
            case 400:
                return "BAD_REQUEST_ERROR";
            case 401:
                return "UNAUTHORIZED_ERROR";
            case 403:
                return "FORBIDDEN_ERROR";
            case 404:
                return "NOT_FOUND_ERROR";
            case 412:
                return "PRECONDITION_FAILED";
            case 409:
                return "CONFLICT_ERROR";
            case 500:
                return "SERVER_ERROR";
            default:
                return "UNKNOWN_ERROR";
        }
    }
};
var CancelablePromise = (function () {
    function CancelablePromise(promise) {
        var _this = this;
        this.wrappedPromise = new Promise(function (resolve, reject) {
            promise.then(function (val) {
                return _this.isCanceled ? reject({ isCanceled: true }) : resolve(val);
            });
            promise.catch(function (error) {
                return _this.isCanceled ? reject({ isCanceled: true }) : reject(error);
            });
        });
    }
    CancelablePromise.prototype.getPromise = function () {
        return this.wrappedPromise;
    };
    CancelablePromise.prototype.cancel = function () {
        this.isCanceled = true;
    };
    return CancelablePromise;
}());
export { CancelablePromise };
//# sourceMappingURL=shared.utils.js.map