import { Component, Input, Output, EventEmitter } from '@angular/core';
import { TAG_DETAIL_STYLES } from './tag-detail.component.css';
import { TAG_DETAIL_HTML } from './tag-detail.component.html';
import { TagService, VulnerabilitySeverity } from '../service/index';
import { toPromise } from '../utils';
import { ErrorHandler } from '../error-handler/index';
var TagDetailComponent = (function () {
    function TagDetailComponent(tagService, errorHandler) {
        this.tagService = tagService;
        this.errorHandler = errorHandler;
        this._highCount = 0;
        this._mediumCount = 0;
        this._lowCount = 0;
        this._unknownCount = 0;
        this.tagDetails = {
            name: "--",
            size: "--",
            author: "--",
            created: new Date(),
            architecture: "--",
            os: "--",
            docker_version: "--",
            digest: "--",
            labels: [],
        };
        this.backEvt = new EventEmitter();
    }
    TagDetailComponent.prototype.ngOnInit = function () {
        var _this = this;
        if (this.repositoryId && this.tagId) {
            toPromise(this.tagService.getTag(this.repositoryId, this.tagId))
                .then(function (response) {
                _this.tagDetails = response;
                if (_this.tagDetails &&
                    _this.tagDetails.scan_overview &&
                    _this.tagDetails.scan_overview.components &&
                    _this.tagDetails.scan_overview.components.summary) {
                    _this.tagDetails.scan_overview.components.summary.forEach(function (item) {
                        switch (item.severity) {
                            case VulnerabilitySeverity.UNKNOWN:
                                _this._unknownCount += item.count;
                                break;
                            case VulnerabilitySeverity.LOW:
                                _this._lowCount += item.count;
                                break;
                            case VulnerabilitySeverity.MEDIUM:
                                _this._mediumCount += item.count;
                                break;
                            case VulnerabilitySeverity.HIGH:
                                _this._highCount += item.count;
                                break;
                            default:
                                break;
                        }
                    });
                }
            })
                .catch(function (error) { return _this.errorHandler.error(error); });
        }
    };
    TagDetailComponent.prototype.onBack = function () {
        this.backEvt.emit(this.repositoryId);
    };
    TagDetailComponent.prototype.getPackageText = function (count) {
        return count > 1 ? "VULNERABILITY.PACKAGES" : "VULNERABILITY.PACKAGE";
    };
    Object.defineProperty(TagDetailComponent.prototype, "author", {
        get: function () {
            return this.tagDetails && this.tagDetails.author ? this.tagDetails.author : 'TAG.ANONYMITY';
        },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(TagDetailComponent.prototype, "highCount", {
        get: function () {
            return this._highCount;
        },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(TagDetailComponent.prototype, "mediumCount", {
        get: function () {
            return this._mediumCount;
        },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(TagDetailComponent.prototype, "lowCount", {
        get: function () {
            return this._lowCount;
        },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(TagDetailComponent.prototype, "unknownCount", {
        get: function () {
            return this._unknownCount;
        },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(TagDetailComponent.prototype, "scanCompletedDatetime", {
        get: function () {
            return this.tagDetails && this.tagDetails.scan_overview ?
                this.tagDetails.scan_overview.update_time : null;
        },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(TagDetailComponent.prototype, "suffixForHigh", {
        get: function () {
            return this.highCount > 1 ? "VULNERABILITY.PLURAL" : "VULNERABILITY.SINGULAR";
        },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(TagDetailComponent.prototype, "suffixForMedium", {
        get: function () {
            return this.mediumCount > 1 ? "VULNERABILITY.PLURAL" : "VULNERABILITY.SINGULAR";
        },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(TagDetailComponent.prototype, "suffixForLow", {
        get: function () {
            return this.lowCount > 1 ? "VULNERABILITY.PLURAL" : "VULNERABILITY.SINGULAR";
        },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(TagDetailComponent.prototype, "suffixForUnknown", {
        get: function () {
            return this.unknownCount > 1 ? "VULNERABILITY.PLURAL" : "VULNERABILITY.SINGULAR";
        },
        enumerable: true,
        configurable: true
    });
    return TagDetailComponent;
}());
export { TagDetailComponent };
TagDetailComponent.decorators = [
    { type: Component, args: [{
                selector: 'hbr-tag-detail',
                styles: [TAG_DETAIL_STYLES],
                template: TAG_DETAIL_HTML,
                providers: []
            },] },
];
/** @nocollapse */
TagDetailComponent.ctorParameters = function () { return [
    { type: TagService, },
    { type: ErrorHandler, },
]; };
TagDetailComponent.propDecorators = {
    'tagId': [{ type: Input },],
    'repositoryId': [{ type: Input },],
    'withAdmiral': [{ type: Input },],
    'withClair': [{ type: Input },],
    'backEvt': [{ type: Output },],
};
//# sourceMappingURL=tag-detail.component.js.map