import { Observable } from 'rxjs/Observable';
import 'rxjs/add/operator/toPromise';
import { RequestOptions, Headers } from '@angular/http';
/**
 * Convert the different async channels to the Promise<T> type.
 *
 * @export
 * @template T
 * @param {(Observable<T> | Promise<T> | T)} async
 * @returns {Promise<T>}
 */
export function toPromise(async) {
    if (!async) {
        return Promise.reject("Bad argument");
    }
    if (async instanceof Observable) {
        var obs = async;
        return obs.toPromise();
    }
    else {
        return Promise.resolve(async);
    }
}
/**
 * The default cookie key used to store current used language preference.
 */
export var DEFAULT_LANG_COOKIE_KEY = 'harbor-lang';
/**
 * Declare what languages are supported now.
 */
export var DEFAULT_SUPPORTING_LANGS = ['en-us', 'zh-cn', 'es-es'];
/**
 * The default language.
 */
export var DEFAULT_LANG = 'en-us';
export var HTTP_JSON_OPTIONS = new RequestOptions({
    headers: new Headers({
        "Content-Type": 'application/json',
        "Accept": 'application/json'
    })
});
export var HTTP_GET_OPTIONS = new RequestOptions({
    headers: new Headers({
        "Content-Type": 'application/json',
        "Accept": 'application/json',
        "Cache-Control": 'no-cache',
        "Pragma": 'no-cache'
    })
});
/**
 * Build http request options
 *
 * @export
 * @param {RequestQueryParams} params
 * @returns {RequestOptions}
 */
export function buildHttpRequestOptions(params) {
    var reqOptions = new RequestOptions({
        headers: new Headers({
            "Content-Type": 'application/json',
            "Accept": 'application/json',
            "Cache-Control": 'no-cache',
            "Pragma": 'no-cache'
        })
    });
    if (params) {
        reqOptions.search = params;
    }
    return reqOptions;
}
/** Button events to pass to `DebugElement.triggerEventHandler` for RouterLink event handler */
export var ButtonClickEvents = {
    left: { button: 0 },
    right: { button: 2 }
};
/** Simulate element click. Defaults to mouse left-button click event. */
export function click(el, eventObj) {
    if (eventObj === void 0) { eventObj = ButtonClickEvents.left; }
    if (el instanceof HTMLElement) {
        el.click();
    }
    else {
        el.triggerEventHandler('click', eventObj);
    }
}
/**
 * Comparator for fields with specific type.
 *
 */
var CustomComparator = (function () {
    function CustomComparator(fieldName, type) {
        this.fieldName = fieldName;
        this.type = type;
    }
    CustomComparator.prototype.compare = function (a, b) {
        var comp = 0;
        if (a && b) {
            var fieldA = a[this.fieldName];
            var fieldB = b[this.fieldName];
            switch (this.type) {
                case "number":
                    comp = fieldB - fieldA;
                    break;
                case "date":
                    comp = new Date(fieldB).getTime() - new Date(fieldA).getTime();
                    break;
            }
        }
        return comp;
    };
    return CustomComparator;
}());
export { CustomComparator };
/**
 * The default page size
 */
export var DEFAULT_PAGE_SIZE = 15;
/**
 * The state of vulnerability scanning
 */
export var VULNERABILITY_SCAN_STATUS = {
    unknown: "n/a",
    pending: "pending",
    running: "running",
    error: "error",
    stopped: "stopped",
    finished: "finished"
};
/**
 * Calculate page number by state
 */
export function calculatePage(state) {
    if (!state || !state.page) {
        return 1;
    }
    return Math.ceil((state.page.to + 1) / state.page.size);
}
/**
 * Filter columns via RegExp
 *
 * @export
 * @param {State} state
 * @returns {void}
 */
export function doFiltering(items, state) {
    if (!items || items.length === 0) {
        return items;
    }
    if (!state || !state.filters || state.filters.length === 0) {
        return items;
    }
    state.filters.forEach(function (filter) {
        items = items.filter(function (item) {
            if (filter['property'].indexOf('.') !== -1) {
                var arr_1 = filter['property'].split('.');
                if (Array.isArray(item[arr_1[0]]) && item[arr_1[0]].length) {
                    return item[arr_1[0]].some(function (data) {
                        return regexpFilter(filter['value'], data[arr_1[1]]);
                    });
                }
            }
            else {
                return regexpFilter(filter['value'], item[filter['property']]);
            }
        });
    });
    return items;
}
/**
 * Match items via RegExp
 *
 * @export
 * @param {string} terms
 * @param {*} testedValue
 * @returns {boolean}
 */
export function regexpFilter(terms, testedValue) {
    var reg = new RegExp('.*' + terms + '.*', 'i');
    return reg.test(testedValue);
}
/**
 * Sorting the data by column
 *
 * @export
 * @template T
 * @param {T[]} items
 * @param {State} state
 * @returns {T[]}
 */
export function doSorting(items, state) {
    if (!items || items.length === 0) {
        return items;
    }
    if (!state || !state.sort) {
        return items;
    }
    return items.sort(function (a, b) {
        var comp = 0;
        if (typeof state.sort.by !== "string") {
            comp = state.sort.by.compare(a, b);
        }
        else {
            var propA = a[state.sort.by.toString()], propB = b[state.sort.by.toString()];
            if (typeof propA === "string") {
                comp = propA.localeCompare(propB);
            }
            else {
                if (propA > propB) {
                    comp = 1;
                }
                else if (propA < propB) {
                    comp = -1;
                }
            }
        }
        if (state.sort.reverse) {
            comp = -comp;
        }
        return comp;
    });
}
/**
 * Compare the two objects to adjust if they're equal
 *
 * @export
 * @param {*} a
 * @param {*} b
 * @returns {boolean}
 */
export function compareValue(a, b) {
    if ((a && !b) || (!a && b))
        return false;
    if (!a && !b)
        return true;
    return JSON.stringify(a) === JSON.stringify(b);
}
/**
 * Check if the object is null or empty '{}'
 *
 * @export
 * @param {*} obj
 * @returns {boolean}
 */
export function isEmptyObject(obj) {
    return !obj || JSON.stringify(obj) === "{}";
}
/**
 * Deeper clone all
 *
 * @export
 * @param {*} srcObj
 * @returns {*}
 */
export function clone(srcObj) {
    if (!srcObj) {
        return null;
    }
    ;
    return JSON.parse(JSON.stringify(srcObj));
}
//# sourceMappingURL=utils.js.map