import { Component, Input } from '@angular/core';
import { ScanningResultService, VulnerabilitySeverity } from '../service/index';
import { ErrorHandler } from '../error-handler/index';
import { toPromise } from '../utils';
import { GRID_COMPONENT_HTML } from './scanning.html';
import { SCANNING_STYLES } from './scanning.css';
import { ChannelService } from "../channel/channel.service";
var ResultGridComponent = (function () {
    function ResultGridComponent(scanningService, channel, errorHandler) {
        this.scanningService = scanningService;
        this.channel = channel;
        this.errorHandler = errorHandler;
        this.scanningResults = [];
        this.dataCache = [];
    }
    ResultGridComponent.prototype.ngOnInit = function () {
        this.loadResults(this.repositoryId, this.tagId);
    };
    ResultGridComponent.prototype.loadResults = function (repositoryId, tagId) {
        var _this = this;
        toPromise(this.scanningService.getVulnerabilityScanningResults(repositoryId, tagId))
            .then(function (results) {
            _this.dataCache = results;
            _this.scanningResults = _this.dataCache.filter(function (item) { return item.id !== ''; });
        })
            .catch(function (error) { _this.errorHandler.error(error); });
    };
    //TODO: Should query from back-end service
    ResultGridComponent.prototype.filterVulnerabilities = function (terms) {
        var _this = this;
        if (terms.trim() === '') {
            this.scanningResults = this.dataCache.filter(function (item) { return item.id !== ''; });
        }
        else {
            this.scanningResults = this.dataCache.filter(function (item) { return _this._regexpFilter(terms, item.package); });
        }
    };
    ResultGridComponent.prototype.refresh = function () {
        this.loadResults(this.repositoryId, this.tagId);
    };
    ResultGridComponent.prototype.severityText = function (severity) {
        switch (severity) {
            case VulnerabilitySeverity.HIGH:
                return 'VULNERABILITY.SEVERITY.HIGH';
            case VulnerabilitySeverity.MEDIUM:
                return 'VULNERABILITY.SEVERITY.MEDIUM';
            case VulnerabilitySeverity.LOW:
                return 'VULNERABILITY.SEVERITY.LOW';
            case VulnerabilitySeverity.NONE:
                return 'VULNERABILITY.SEVERITY.NEGLIGIBLE';
            case VulnerabilitySeverity.UNKNOWN:
                return 'VULNERABILITY.SEVERITY.UNKNOWN';
            default:
                return 'UNKNOWN';
        }
    };
    ResultGridComponent.prototype._regexpFilter = function (terms, testedValue) {
        var reg = new RegExp('.*' + terms + '.*', 'i');
        return reg.test(testedValue);
    };
    ResultGridComponent.prototype.scanNow = function () {
        this.channel.publishScanEvent(this.repositoryId + "/" + this.tagId);
    };
    return ResultGridComponent;
}());
export { ResultGridComponent };
ResultGridComponent.decorators = [
    { type: Component, args: [{
                selector: 'hbr-vulnerabilities-grid',
                styles: [SCANNING_STYLES],
                template: GRID_COMPONENT_HTML
            },] },
];
/** @nocollapse */
ResultGridComponent.ctorParameters = function () { return [
    { type: ScanningResultService, },
    { type: ChannelService, },
    { type: ErrorHandler, },
]; };
ResultGridComponent.propDecorators = {
    'tagId': [{ type: Input },],
    'repositoryId': [{ type: Input },],
};
//# sourceMappingURL=result-grid.component.js.map