import { Component, Input } from '@angular/core';
import { VulnerabilitySeverity } from '../service/index';
import { TranslateService } from '@ngx-translate/core';
import { SCANNING_STYLES } from './scanning.css';
import { TIP_COMPONENT_HTML } from './scanning.html';
import { VULNERABILITY_SCAN_STATUS } from '../utils';
export var MIN_TIP_WIDTH = 5;
export var MAX_TIP_WIDTH = 100;
var ResultTipComponent = (function () {
    function ResultTipComponent(translate) {
        this.translate = translate;
        this._tipTitle = "";
        this._highCount = 0;
        this._mediumCount = 0;
        this._lowCount = 0;
        this._unknownCount = 0;
        this._noneCount = 0;
        this.totalPackages = 0;
        this.packagesWithVul = 0;
        this.summary = {
            scan_status: VULNERABILITY_SCAN_STATUS.unknown,
            severity: VulnerabilitySeverity.UNKNOWN,
            update_time: new Date(),
            components: {
                total: 0,
                summary: []
            }
        };
    }
    Object.defineProperty(ResultTipComponent.prototype, "scanLevel", {
        get: function () {
            var level;
            if (this._highCount && this._highCount >= 1) {
                level = VulnerabilitySeverity.HIGH;
            }
            else if (this._mediumCount && this._mediumCount >= 1) {
                level = VulnerabilitySeverity.MEDIUM;
            }
            else if (this._lowCount && this._lowCount >= 1) {
                level = VulnerabilitySeverity.LOW;
            }
            else if (this._unknownCount && this._unknownCount >= 1) {
                level = VulnerabilitySeverity.UNKNOWN;
            }
            else if (this.totalPackages == 0) {
                level = VulnerabilitySeverity.UNKNOWN;
            }
            else {
                level = VulnerabilitySeverity.NONE;
            }
            return level;
        },
        enumerable: true,
        configurable: true
    });
    ResultTipComponent.prototype.ngOnInit = function () {
        var _this = this;
        this.totalPackages = this.summary && this.summary.components ? this.summary.components.total : 0;
        if (this.summary && this.summary.components && this.summary.components.summary) {
            this.summary.components.summary.forEach(function (item) {
                if (item.severity != VulnerabilitySeverity.NONE) {
                    _this.packagesWithVul += item.count;
                }
                switch (item.severity) {
                    case VulnerabilitySeverity.UNKNOWN:
                        _this._unknownCount += item.count;
                        break;
                    case VulnerabilitySeverity.NONE:
                        _this._noneCount += item.count;
                        break;
                    case VulnerabilitySeverity.LOW:
                        _this._lowCount += item.count;
                        break;
                    case VulnerabilitySeverity.MEDIUM:
                        _this._mediumCount += item.count;
                        break;
                    case VulnerabilitySeverity.HIGH:
                        _this._highCount += item.count;
                        break;
                    default:
                        break;
                }
            });
        }
        this.translate.get(this.packageText(this.totalPackages)).subscribe(function (p1) {
            _this.translate.get(_this.unitText(_this.packagesWithVul)).subscribe(function (vul) {
                if (_this.totalPackages === 0) {
                    _this.translate.get('VULNERABILITY.CHART.TOOLTIPS_TITLE_ZERO').subscribe(function (res) {
                        _this._tipTitle = res;
                    });
                }
                else {
                    var messageKey = 'VULNERABILITY.CHART.TOOLTIPS_TITLE_SINGULAR';
                    if (_this.packagesWithVul > 1) {
                        messageKey = 'VULNERABILITY.CHART.TOOLTIPS_TITLE';
                    }
                    _this.translate.get(messageKey, {
                        totalVulnerability: _this.packagesWithVul,
                        totalPackages: _this.totalPackages,
                        package: p1,
                        vulnerability: vul
                    }).subscribe(function (res) { return _this._tipTitle = res; });
                }
            });
        });
    };
    ResultTipComponent.prototype.tipWidth = function (severity) {
        var n = 0;
        var m = this.totalPackages;
        if (m === 0) {
            //If no packages recognized, then show grey
            if (severity === VulnerabilitySeverity.UNKNOWN) {
                return MAX_TIP_WIDTH + 'px';
            }
            else {
                return 0 + 'px';
            }
        }
        switch (severity) {
            case VulnerabilitySeverity.HIGH:
                n = this.highCount;
                break;
            case VulnerabilitySeverity.MEDIUM:
                n = this.mediumCount;
                break;
            case VulnerabilitySeverity.LOW:
                n = this.lowCount;
                break;
            case VulnerabilitySeverity.UNKNOWN:
                n = this.unknownCount;
                break;
            case VulnerabilitySeverity.NONE:
                //Show all the left as green bar
                n = m - (this.highCount + this.mediumCount + this.lowCount + this.unknownCount);
                if (n < 0) {
                    n = 0;
                }
                break;
            default:
                n = 0;
                break;
        }
        var width = Math.round((n / m) * MAX_TIP_WIDTH);
        if (width > 0 && width < MIN_TIP_WIDTH) {
            width = MIN_TIP_WIDTH;
        }
        return width + 'px';
    };
    ResultTipComponent.prototype.unitText = function (count) {
        if (count > 1) {
            return "VULNERABILITY.PLURAL";
        }
        return "VULNERABILITY.SINGULAR";
    };
    ResultTipComponent.prototype.packageText = function (count) {
        return count > 1 ? "VULNERABILITY.PACKAGES" : "VULNERABILITY.PACKAGE";
    };
    Object.defineProperty(ResultTipComponent.prototype, "completeTimestamp", {
        get: function () {
            return this.summary && this.summary.update_time ? this.summary.update_time : new Date();
        },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(ResultTipComponent.prototype, "hasHigh", {
        get: function () {
            return this.highCount > 0;
        },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(ResultTipComponent.prototype, "hasMedium", {
        get: function () {
            return this.mediumCount > 0;
        },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(ResultTipComponent.prototype, "hasLow", {
        get: function () {
            return this.lowCount > 0;
        },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(ResultTipComponent.prototype, "hasUnknown", {
        get: function () {
            return this.unknownCount > 0;
        },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(ResultTipComponent.prototype, "hasNone", {
        get: function () {
            return this.noneCount > 0;
        },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(ResultTipComponent.prototype, "tipTitle", {
        get: function () {
            return this._tipTitle;
        },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(ResultTipComponent.prototype, "highCount", {
        get: function () {
            return this._highCount;
        },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(ResultTipComponent.prototype, "mediumCount", {
        get: function () {
            return this._mediumCount;
        },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(ResultTipComponent.prototype, "lowCount", {
        get: function () {
            return this._lowCount;
        },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(ResultTipComponent.prototype, "unknownCount", {
        get: function () {
            return this._unknownCount;
        },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(ResultTipComponent.prototype, "noneCount", {
        get: function () {
            return this._noneCount;
        },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(ResultTipComponent.prototype, "highSuffix", {
        get: function () {
            return this.unitText(this.highCount);
        },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(ResultTipComponent.prototype, "mediumSuffix", {
        get: function () {
            return this.unitText(this.mediumCount);
        },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(ResultTipComponent.prototype, "lowSuffix", {
        get: function () {
            return this.unitText(this.lowCount);
        },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(ResultTipComponent.prototype, "unknownSuffix", {
        get: function () {
            return this.unitText(this.unknownCount);
        },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(ResultTipComponent.prototype, "noneSuffix", {
        get: function () {
            return this.unitText(this.noneCount);
        },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(ResultTipComponent.prototype, "maxWidth", {
        get: function () {
            return (MAX_TIP_WIDTH + 20) + "px";
        },
        enumerable: true,
        configurable: true
    });
    return ResultTipComponent;
}());
export { ResultTipComponent };
ResultTipComponent.decorators = [
    { type: Component, args: [{
                selector: 'hbr-vulnerability-summary-chart',
                template: TIP_COMPONENT_HTML,
                styles: [SCANNING_STYLES]
            },] },
];
/** @nocollapse */
ResultTipComponent.ctorParameters = function () { return [
    { type: TranslateService, },
]; };
ResultTipComponent.propDecorators = {
    'summary': [{ type: Input },],
};
//# sourceMappingURL=result-tip.component.js.map